<?php

namespace EventPortal\Domain\Component\Filter;

use Illuminate\Database\Eloquent\Builder;
use Illuminate\Support\Str;

abstract class Filter
{
    /** @var string */
    public $label;

    /** @var string */
    public $key;

    /** @var string */
    public $type;

    /** @var string */
    public $name;

    /** @var string */
    public $relatedColumn;

    /** @var callable */
    public $lookup;

    public function __construct(string $label)
    {
        $this->label = $label;
        $this->name = $label !== null ? Str::slug($label, '_') : null;
        $this->key = $this->name;
    }

    public static function make(string $label): self
    {
        return new static($label);
    }

    public function name(string $name): self
    {
        $this->name = $name;
        $this->key = $name;

        return $this;
    }

    public function lookup(callable $callback): self
    {
        $this->lookup = $callback;

        return $this;
    }

    public function forColumn(string $column): self
    {
        $this->relatedColumn = $column;
        $this->name = $column;

        return $this;
    }

    public function hasManualLookup(): bool
    {
        return $this->lookup !== null;
    }

    public function applyLookup(Builder $query, string $value, string $field): Builder
    {
        if ($this->lookup === null) {
            return $query->where($field, $value);
        }

        return $this->lookup->__invoke($query, $value, $field);
    }
}
