<?php

namespace EventPortal\Tests\Feature\Admin\Email;

use Carbon\Carbon;
use EventPortal\Domain\Admin\Models\Admin;
use EventPortal\Domain\Email\Models\EventEmail;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Domain\Permission\Models\Permission;
use EventPortal\Http\Middleware\CurrentTeam;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Spatie\Snapshots\MatchesSnapshots;

class EmailIndexTest extends TestCase
{
    use DatabaseMigrations, MatchesSnapshots;

    /** @test **/
    public function can_see_emails_for_an_event()
    {
        Carbon::setTestNow(Carbon::parse('1 September 2020'));
        $admin = factory(Admin::class)->create();
        $event = factory(Event::class)->state('snapshot')->create();
        factory(EventEmail::class)->create([
            'event_id' => $event,
        ]);

        $admin->givePermissionTo([
            factory(Permission::class)->create([
                'name' => 'email.index',
            ]),
            factory(Permission::class)->create([
                'name' => 'email.show',
            ]),
        ]);

        $this->withoutMiddleware(CurrentTeam::class)
            ->assertMatchesJsonSnapshot(
                $this->actingAs($admin->user)
                    ->get(route('admin.email.index', [
                        'event' => $event,
                    ]))->props()
            );
    }
}
